# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Name:		perl-HTTP-Tiny
Version:	0.088
Release:	1.%{__distinit}%{__distvers}
Summary:	Small, simple, correct HTTP/1.1 client
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/HTTP-Tiny
Source0:	https://cpan.metacpan.org/modules/by-module/HTTP/HTTP-Tiny-%{version}.tar.gz
Patch0:		HTTP-Tiny-0.070-Croak-on-failed-write-into-a-file.patch
BuildArch:	noarch
# Build:
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker) >= 6.17
# Run-time:
BuildRequires:	perl(bytes)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Errno)
BuildRequires:	perl(Fcntl)
BuildRequires:	perl(IO::Socket)
BuildRequires:	perl(MIME::Base64)
# Mozilla::CA is optional; falls back to system certificate bundle
BuildRequires:	perl(Socket)
BuildRequires:	perl(strict)
BuildRequires:	perl(threads)
BuildRequires:	perl(Time::Local)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(Data::Dumper)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(File::Basename) 
BuildRequires:	perl(File::Spec)
BuildRequires:	perl(File::Temp)
BuildRequires:	perl(IO::Dir)
BuildRequires:	perl(IO::File)
BuildRequires:	perl(IO::Socket::INET)
BuildRequires:	perl(IPC::Cmd)
BuildRequires:	perl(lib)
BuildRequires:	perl(open)
BuildRequires:	perl(Test::More) >= 0.96
# Optional Tests
BuildRequires:	perl(CPAN::Meta) >= 2.120900
BuildRequires:	perl(CPAN::Meta::Prereqs)
BuildRequires:	perl(Mozilla::CA)
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(bytes)
Requires:	perl(Carp)
Requires:	perl(Fcntl)
Requires:	perl(MIME::Base64)
Requires:	perl(threads)
Requires:	perl(Time::Local)

# Optional SSL support; this will also pull in IO::Socket::IP where available for IPv6 support
BuildRequires:	perl(IO::Socket::SSL) >= 1.56
BuildRequires:	perl(Net::SSLeay) >= 1.49
Requires:	perl(IO::Socket::SSL) >= 1.56
Requires:	perl(Net::SSLeay) >= 1.49

%description
This is a very simple HTTP/1.1 client, designed for doing simple GET requests
without the overhead of a large framework like LWP::UserAgent.

It is more correct and more complete than HTTP::Lite. It supports proxies
(currently only non-authenticating ones) and redirection. It also correctly
resumes after EINTR.

%prep
%setup -q -n HTTP-Tiny-%{version}

# Check for write failure (#1031096), refused by upstream,
# <https://github.com/chansen/p5-http-tiny/issues/32>
%patch -P 0

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test

%files
%license LICENSE
%doc Changes CONTRIBUTING.mkdn eg/ README
%{perl_vendorlib}/HTTP/
%{_mandir}/man3/HTTP::Tiny.3*

%changelog
* Wed Jul 12 2023 Paul Howarth <paul@city-fan.org> - 0.088-1
- Update to 0.088
  - Update metadata to point to new Perl-Toolchain-Gang repository

* Fri Jun 23 2023 Paul Howarth <paul@city-fan.org> - 0.086-1
- Update to 0.086
  - Fix code to use $ENV{PERL_HTTP_TINY_SSL_INSECURE_BY_DEFAULT} as documented

* Thu Jun 15 2023 Paul Howarth <paul@city-fan.org> - 0.084-1
- Update to 0.084
  - Change the 'verify_SSL' parameter default value from '0' to '1'
    (CVE-2023-31486)
  - '$ENV{PERL_HTTP_TINY_SSL_INSECURE_BY_DEFAULT}' can be used to restore the
    old default if required
- Use SPDX-format license tag
- Avoid use of deprecated patch syntax

* Tue Jul 26 2022 Paul Howarth <paul@city-fan.org> - 0.082-1
- Update to 0.082
  - No longer deletes the 'headers' key from post_form arguments hashref
  - Documented that request/response content are handled as raw bytes

* Sun Nov  7 2021 Paul Howarth <paul@city-fan.org> - 0.080-1
- Update to 0.080
  - Fixed uninitialized value warnings on older Perls when the REQUEST_METHOD
    environment variable is set and CGI_HTTP_PROXY is not

* Tue Aug  3 2021 Paul Howarth <paul@city-fan.org> - 0.078-1
- Update to 0.078
  - Added a 'patch' helper method for the HTTP 'PATCH' verb
  - If the REQUEST_METHOD environment variable is set, then CGI_HTTP_PROXY
    replaces HTTP_PROXY
  - Unsupported scheme errors early without giving an uninitialized value
    warning first
  - Sends Content-Length: 0 on empty body PUT/POST; this is not in the spec,
    but some servers require this
  - Allows optional status line reason, as clarified in RFC 7230
  - Ignore SIGPIPE on reads as well as writes, as IO::Socket::SSL says that SSL
    reads can also send writes as a side effect
  - Check if a server has closed a connection before preserving it for reuse
  - Clarified documentation that exceptions/errors result in 599 status codes
  - Optional IO::Socket::IP prereq must be at least version 0.32 to be used;
    this ensures correct timeout support
- Fix dist tags for Alma and Rocky Linux

* Tue Apr  6 2021 Paul Howarth <paul@city-fan.org> - 0.076-458
- Avoid failing online test by not specifying AUTOMETED_TESTING
- Use %%license unconditionally

* Mon Jun 29 2020 Paul Howarth <paul@city-fan.org> - 0.076-456
- Perl 5.32 rebuild

* Thu Jun  6 2019 Paul Howarth <paul@city-fan.org> - 0.076-438
- Perl 5.30 rebuild

* Mon Aug 20 2018 Paul Howarth <paul@city-fan.org> - 0.076-1
- Update to 0.076
  - The 'peer' option now also can take a code reference

* Wed Aug  1 2018 Paul Howarth <paul@city-fan.org> - 0.074-1
- Update to 0.074
  - Documented that method argument to request() is case-sensitive
  - Documented 'protocol' field in response hash
  - Minor regex cleanup
  - Updated .travis.yml for recent Perls
- Drop BR: perl(Mozilla::CA) prior to Fedora 18 (versions too old now)
- Switch upstream from search.cpan.org to metacpan.org
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Drop workaround for building with Test::More < 0.96

* Mon Oct 10 2016 Paul Howarth <paul@city-fan.org> - 0.070-1
- Update to 0.070
  - Lazy load Carp only if needed
- Update croak-on-failed-write patch

* Sun Sep 25 2016 Paul Howarth <paul@city-fan.org> - 0.068-1
- Update to 0.068
  - Try harder to clean up environment in t/140_proxy.t (needed for VMS)
  - Includes redirect history when issuing a 599 internal error

* Wed Aug 17 2016 Paul Howarth <paul@city-fan.org> - 0.064-1
- Update to 0.064
  Fixed
  - Timeout can now be set as a constructor argument again
  - Avoid loading optional modules from @INC path with '.' at the end
    (CVE-2016-1238)
  - Avoid overwriting 'If-Modified-Since' header in mirror() if the header
    already exists in something other than lower-case
  - Fixed chunked transfer encoding, which previously omitted a trailing CRLF
  Tests
  - Updated tests for a future perl which may omit '.' from the list of
    directories in @INC by default
  - Normalize CRLF when reading test data files in t/150-post_form.t on Win32
- Update croak-on-failed-write patch

* Wed Aug  3 2016 Paul Howarth <paul@city-fan.org> - 0.058-3
- Avoid loading optional modules from default . (CVE-2016-1238)
- BR: perl-generators where possible

* Wed May  4 2016 Paul Howarth <paul@city-fan.org> - 0.058-1
- Update to 0.058
  Added
  - Added support for the SSL_CERT_FILE environment variable
  - Added 'peer' attribute to force a connection to a particular server
  - Added 'connected' method to allow introspection of persistent connections
  - An array reference of redirection result hash references is included in
    the final response hash reference (but only if redirects occur)
  Changed
  - Because folded headers are obsoleted in the revised RFCs, if CRLF is found
    in header values followed by one or more spaces, they are all replaced by
    a single space
  Fixed
  - Per the RFC, control headers are now sent first before other headers
    (which are sent in arbitrary order)
  - Only well-known headers have their case canonicalized; all other headers
    are sent in the case provided by the user
  - The 'keep_alive' option now also sets the SO_KEEPALIVE option on the
    underlying socket to help with long-lived, idle connections
  - Request header field values are now validated against the RFC rules (i.e.
    empty or else space-or-tab separated tokens of printable characters)
- Simplify find command using -delete

* Sat Jun 27 2015 Paul Howarth <paul@city-fan.org> - 0.056-3
- Perl 5.22 rebuild

* Tue May 19 2015 Paul Howarth <paul@city-fan.org> - 0.056-1
- Update to 0.056
  - Added 'can_ssl' method to detect SSL support before trying and failing
    with a fatal exception
  - Added support for 308 redirects
  - When specifying a custom CA file, if that file is missing or unreadable,
    HTTP::Tiny will no longer fall back to a default CA
  - Documented that units are bytes for max_size

* Tue Jan 27 2015 Paul Howarth <paul@city-fan.org> - 0.054-1
- Update to 0.054
  - Added more fallback paths to find CA files
  - Fixed a typo in an error message

* Mon Dec 15 2014 Paul Howarth <paul@city-fan.org> - 0.053-1
- Update to 0.053
  - Proxy allowed from environment variable HTTP_PROXY (uppercase) unless
    REQUEST_METHOD is also set
  - Defended tests against HTTP_PROXY set in the environment

* Tue Nov 18 2014 Paul Howarth <paul@city-fan.org> - 0.051-1
- Update to 0.051
  - Checks for threads without loading threads.pm

* Thu Sep 25 2014 Paul Howarth <paul@city-fan.org> - 0.050-1
- Update to 0.050
  - Fixed CONNECT requests for some proxies

* Fri Sep  5 2014 Paul Howarth <paul@city-fan.org> - 0.049-1
- Update to 0.049
  - 'keep_alive' is now fork-safe and thread-safe
- BR/R: perl(threads)

* Tue Aug 26 2014 Paul Howarth <paul@city-fan.org> - 0.048-1
- Update to 0.048
  - Protected proxy tests from ALL_PROXY in the environment

* Wed Jul 30 2014 Paul Howarth <paul@city-fan.org> - 0.047-1
- Update to 0.047
  - Updated Mozilla::CA module recommendation version to 20130114
  - Fixed t/00-report-prereqs.t when CPAN::Meta is not installed

* Mon Jul 21 2014 Paul Howarth <paul@city-fan.org> - 0.046-1
- Update to 0.046
  - Fixed t/002_croakage.t for various operating systems
  - Empty header fields are now allowed; headers with the 'undef' value will
    be rendered as an empty header
  - Updated HTTP/1.1 spec description from RFC 2616 to RFC 7230-7235
- Use %%license where possible

* Thu Jul 17 2014 Paul Howarth <paul@city-fan.org> - 0.044-1
- Update to 0.044
  - Providing a custom 'Host' header is now a fatal exception; previously, it
    was silently ignored, as the RFC mandates that Host be set from the URL,
    but ignoring it could lead to unexpected, confusing errors
  - Optimized URL splitting
  - Passing 'undef' for any proxy attribute will prevent HTTP::Tiny from
    setting the proxy from the environment
- Update croak-on-failed-write patch

* Mon May 19 2014 Paul Howarth <paul@city-fan.org> - 0.043-3
- Bundle Test::More 0.96 so we can build on old distributions

* Wed Apr  2 2014 Paul Howarth <paul@city-fan.org> - 0.043-2
- Import from Fedora

* Fri Feb 21 2014 Petr Pisar <ppisar@redhat.com> - 0.043-1
- 0.043 bump

* Wed Feb 19 2014 Petr Pisar <ppisar@redhat.com> - 0.042-1
- 0.042 bump

* Thu Nov 28 2013 Petr Pisar <ppisar@redhat.com> - 0.039-1
- 0.039 bump

* Wed Nov 27 2013 Petr Pisar <ppisar@redhat.com> - 0.038-2
- Croak on failed write into a file (bug #1031096)
- Do not use already existing temporary files (bug #1031096)

* Tue Nov 19 2013 Petr Pisar <ppisar@redhat.com> - 0.038-1
- 0.038 bump

* Tue Oct 29 2013 Petr Pisar <ppisar@redhat.com> - 0.037-1
- 0.037 bump

* Thu Sep 26 2013 Petr Pisar <ppisar@redhat.com> - 0.036-1
- 0.036 bump

* Wed Sep 11 2013 Petr Pisar <ppisar@redhat.com> - 0.035-1
- 0.035 bump

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.034-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jul 12 2013 Petr Pisar <ppisar@redhat.com> - 0.034-2
- Link minimal build-root packages against libperl.so explicitly

* Mon Jul 01 2013 Petr Pisar <ppisar@redhat.com> - 0.034-1
- 0.034 bump

* Mon Jun 24 2013 Petr Pisar <ppisar@redhat.com> - 0.033-1
- 0.033 bump

* Fri Jun 21 2013 Petr Pisar <ppisar@redhat.com> - 0.032-1
- 0.032 bump

* Thu Jun 20 2013 Petr Pisar <ppisar@redhat.com> - 0.031-1
- 0.031 bump

* Fri Jun 14 2013 Petr Pisar <ppisar@redhat.com> - 0.030-1
- 0.030 bump

* Thu Apr 18 2013 Petr Pisar <ppisar@redhat.com> - 0.029-1
- 0.029 bump

* Fri Mar 15 2013 Petr Pisar <ppisar@redhat.com> 0.028-1
- Specfile autogenerated by cpanspec 1.78
